pyjabber.plugins package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pyjabber.plugins.roster
   pyjabber.plugins.xep_0004
   pyjabber.plugins.xep_0030
   pyjabber.plugins.xep_0060
   pyjabber.plugins.xep_0199

Submodules
----------

pyjabber.plugins.PluginManager module
-------------------------------------

.. automodule:: pyjabber.plugins.PluginManager
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.plugins
   :members:
   :undoc-members:
   :show-inheritance:
